package com.zdqz.web.controller.system;

import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.core.domain.entity.SysUser;
import com.zdqz.common.core.domain.model.LoginUser;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.common.utils.SecurityUtils;
import com.zdqz.common.utils.StringUtils;
import com.zdqz.framework.web.service.TokenService;
import com.zdqz.system.service.ISysUserService;

/**
 * 个人信息 业务处理
 * 
 * @author 攻心小虫
 */
@RestController
@RequestMapping("/system/user/profile")
public class SysProfileController extends BaseController {
	@Autowired
	private ISysUserService userService;

	@Autowired
	private TokenService tokenService;

	/**
	 * 个人信息
	 */
	@GetMapping
	public AjaxResult profile() {
		LoginUser loginUser = getLoginUser();
		SysUser user = loginUser.getUser();
		AjaxResult ajax = AjaxResult.success(user);
		ajax.put("roleGroup", userService.selectUserRoleGroup(loginUser.getUsername()));
		return ajax;
	}

	/**
	 * 修改用户
	 */
	@Log(title = "个人信息", businessType = BusinessType.UPDATE)
	@PutMapping
	public AjaxResult updateProfile(@RequestBody SysUser user) {
		LoginUser loginUser = getLoginUser();
		SysUser currentUser = loginUser.getUser();
		currentUser.setNickName(user.getNickName());
		currentUser.setPhonenumber(user.getPhonenumber());
		if (StringUtils.isNotEmpty(user.getPhonenumber()) && !userService.checkPhoneUnique(currentUser)) {
			return error("修改用户'" + loginUser.getUsername() + "'失败，手机号码已存在");
		}
		if (userService.updateUserProfile(currentUser) > 0) {
			// 更新缓存用户信息
			tokenService.setLoginUser(loginUser);
			return success();
		}
		return error("修改个人信息异常，请联系管理员");
	}

	/**
	 * 重置密码
	 */
	@Log(title = "个人信息", businessType = BusinessType.UPDATE)
	@PutMapping("/updatePwd")
	public AjaxResult updatePwd(@RequestBody Map<String, String> params) {
		String oldPassword = params.get("oldPassword");
		String newPassword = params.get("newPassword");
		LoginUser loginUser = getLoginUser();
		String userName = loginUser.getUsername();
		String password = loginUser.getPassword();
		if (!SecurityUtils.matchesPassword(oldPassword, password)) {
			return error("修改密码失败，旧密码错误");
		}
		if (SecurityUtils.matchesPassword(newPassword, password)) {
			return error("新密码不能与旧密码相同");
		}
		newPassword = SecurityUtils.encryptPassword(newPassword);
		if (userService.resetUserPwd(userName, newPassword) > 0) {
			// 更新缓存用户密码
			loginUser.getUser().setPassword(newPassword);
			tokenService.setLoginUser(loginUser);
			return success();
		}
		return error("修改密码异常，请联系管理员");
	}

}
