package com.zdqz.data.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.core.page.TableDataInfo;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.data.domain.DataBase;
import com.zdqz.data.service.IDataBaseService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 病原体管理Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-05
 */
@RestController
@RequestMapping("/data/dataBase")
@Api(value="基础数据管理接口",tags="基础数据接口标签")
public class DataBaseController extends BaseController {
	@Autowired
	private IDataBaseService dataBaseService;

	/**
	 * 查询病原体管理列表
	 */
	@GetMapping("/list")
	public TableDataInfo list(DataBase dataBase) {
		startPage();
		List<DataBase> list = dataBaseService.selectDataBaseList(dataBase);
		return getDataTable(list);
	}

	/**
	 * 获取病原体管理详细信息
	 */
	@PreAuthorize("@ss.hasPermi('data:dataBase:query')")
	@GetMapping(value = "/{id}")
	public AjaxResult getInfo(@PathVariable("id") String id) {
		return success(dataBaseService.selectDataBaseById(id));
	}

	/**
	 * 删除病原体管理
	 */
	@Log(title = "基础数据管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
	public AjaxResult remove(@PathVariable String[] ids) {
		return toAjax(dataBaseService.deleteDataBaseByIds(ids));
	}
	
	@PostMapping("/importData")
	@ApiOperation("导入基础数据，新增覆盖原来的数据")
	@Log(title = "基础数据管理", businessType = BusinessType.IMPORT)
	public AjaxResult importData(@RequestPart("file") MultipartFile file) throws Exception {
//		ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
//		List<SysUser> userList = util.importExcel(file.getInputStream());
//		String operName = getUsername();
//		String message = userService.importUser(userList, updateSupport, operName);
		return success("后端还未实现，不用管");
	}
}
