package com.zdqz.read.controller;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.read.domain.FilterBean;
import com.zdqz.read.service.IReadDataService;
import com.zdqz.read.service.IReadRemarkService;
import com.zdqz.sample.service.ISampleInfoService;
import com.zdqz.sample.service.ISamplePatientService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

/**
 * 解读数据Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-05
 */
@RestController
@RequestMapping("/read/readData")
@Api(value="解读中心接口",tags="解读中心接口标签")
public class ReadDataController extends BaseController {
	@Autowired
	private IReadDataService readDataService;

	@Autowired
	private ISamplePatientService samplePatientService;
	
	@Autowired
	private ISampleInfoService sampleInfoService;
	
	@Autowired
    private IReadRemarkService readRemarkService;
	
	@ApiOperation("根据实验编号找患者信息")
	@GetMapping(value = "/getPatient/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getPatient(@PathVariable("experimentid") Long experimentid) {
		return success(samplePatientService.selectSamplePatientByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找样品信息")
	@GetMapping(value = "/getSample/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getSample(@PathVariable("experimentid") Long experimentid) {
		return success(sampleInfoService.selectSampleInfoByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找解读备注信息")
	@GetMapping(value = "/getRemark/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getRemark(@PathVariable("experimentid") Long experimentid) {
		return success(readRemarkService.selectReadRemarkByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找病原体信息")
	@GetMapping(value = "/getBYT/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getBYT(@PathVariable("experimentid") Long experimentid) {
		return success(readDataService.selectBYTByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找过滤的病原体信息")
	@GetMapping(value = "/getBYTFilter/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getBYTFilter(@PathVariable("experimentid") Long experimentid) {
		return success(readDataService.selectBYTFilterByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找毒力基因信息")
	@GetMapping(value = "/getDLJY/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getDLJY(@PathVariable("experimentid") Long experimentid) {
		return success(readDataService.selectDLJYByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找过滤的毒力基因信息")
	@GetMapping(value = "/getDLJYFilter/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getDLJYFilter(@PathVariable("experimentid") Long experimentid) {
		return success(readDataService.selectDLJYFilterByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找耐药基因信息")
	@GetMapping(value = "/getNYJY/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getNYJY(@PathVariable("experimentid") Long experimentid) {
		return success(readDataService.selectNYJYByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找过滤的耐药基因信息")
	@GetMapping(value = "/getNYJYFilter/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getNYJYFilter(@PathVariable("experimentid") Long experimentid) {
		return success(readDataService.selectNYJYFilterByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找点突变耐药基因信息")
	@GetMapping(value = "/getDTBNYJY/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getDTBNYJY(@PathVariable("experimentid") Long experimentid) {
		return success(readDataService.selectDTBNYJYByExperiment(experimentid));
	}
	
	@ApiOperation("根据实验编号找过滤的点突变耐药基因信息")
	@GetMapping(value = "/getDTBNYJYFilter/{experimentid}")
	@ApiImplicitParam(name = "experimentid", value = "实验编号", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getDTBNYJYFilter(@PathVariable("experimentid") Long experimentid) {
		return success(readDataService.selectDTBNYJYFilterByExperiment(experimentid));
	}
	
	@ApiOperation("过滤解读数据")
	@PostMapping(value="/saveData")
	@Log(title = "过滤解读数据", businessType = BusinessType.UPDATE)
	public AjaxResult saveData(@RequestBody FilterBean filterBean) {
		readDataService.saveData(filterBean);
		return success();
	}
	
	
}
