package com.zdqz.read.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.zdqz.common.utils.DateUtils;
import com.zdqz.read.domain.FilterBean;
import com.zdqz.read.domain.ReadData;
import com.zdqz.read.domain.ReadRemark;
import com.zdqz.read.mapper.ReadDataMapper;
import com.zdqz.read.service.IReadDataService;
import com.zdqz.read.service.IReadRemarkService;

/**
 * 解读数据Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-05
 */
@Service
public class ReadDataServiceImpl implements IReadDataService {

	@Autowired
	private ReadDataMapper readDataMapper;

	@Autowired
	private IReadRemarkService readRemarkService;

	public int insertReadData(ReadData readData) {
		readData.setCreateTime(DateUtils.getNowDate());
		return readDataMapper.insertReadData(readData);
	}

	public int updateReadData(ReadData readData) {
		readData.setUpdateTime(DateUtils.getNowDate());
		return readDataMapper.updateReadData(readData);
	}

	public void importData(Long experimentId, List<ReadData> importExcel) {
		readDataMapper.setDeleteFlag(experimentId);
		for (ReadData readData : importExcel) {
			readData.setExperimentId(experimentId);
			insertReadData(readData);
		}

		ReadRemark readRemark = new ReadRemark();
		readRemark.setExperimentId(experimentId);
		readRemarkService.insertReadRemark(readRemark);
	}

	public List<ReadData> selectBYTByExperiment(Long experimentid) {
		return readDataMapper.selectBYTByExperiment(experimentid,1);
	}

	public List<ReadData> selectBYTFilterByExperiment(Long experimentid) {
		return readDataMapper.selectBYTByExperiment(experimentid,2);
	}

	public List<ReadData> selectDLJYByExperiment(Long experimentid) {
		return readDataMapper.selectDLJYByExperiment(experimentid,1);
	}

	public List<ReadData> selectDLJYFilterByExperiment(Long experimentid) {
		return readDataMapper.selectDLJYByExperiment(experimentid,2);
	}

	public List<ReadData> selectNYJYByExperiment(Long experimentid) {
		return readDataMapper.selectNYJYByExperiment(experimentid,1);
	}

	public List<ReadData> selectNYJYFilterByExperiment(Long experimentid) {
		return readDataMapper.selectNYJYByExperiment(experimentid,2);
	}

	public List<ReadData> selectDTBNYJYByExperiment(Long experimentid) {
		return readDataMapper.selectDTBNYJYByExperiment(experimentid,1);
	}

	public List<ReadData> selectDTBNYJYFilterByExperiment(Long experimentid) {
		return readDataMapper.selectDTBNYJYByExperiment(experimentid,2);
	}

	@Transactional(rollbackFor = Exception.class)
	public void saveData(FilterBean filterBean) {
		readRemarkService.updateReadRemark(filterBean.getReadremark());	//更新数据
		
		//重置病原体
		readDataMapper.resetBYTFilter(filterBean.getReadremark().getExperimentId());
		if(filterBean.getBYTFilterList() != null && filterBean.getBYTFilterList().length > 0) {
			readDataMapper.setBYTFilter(filterBean.getBYTFilterList());
		}
		
		//重置毒力基因
		readDataMapper.resetDLJYFilter(filterBean.getReadremark().getExperimentId());
		if(filterBean.getDLJYFilterList() != null  && filterBean.getBYTFilterList().length > 0) {
			readDataMapper.setDLJYFilter(filterBean.getDLJYFilterList());
		}
		
		//重置耐药基因
		readDataMapper.resetNYJYFilter(filterBean.getReadremark().getExperimentId());
		if(filterBean.getNYJYFilterList() != null && filterBean.getNYJYFilterList().length > 0) {
			readDataMapper.setNYJYFilter(filterBean.getNYJYFilterList());
		}
		
		//重置点突变耐药基因
		readDataMapper.resetDTBNYJYFilter(filterBean.getReadremark().getExperimentId());
		if(filterBean.getDTBNYJYFilterList() != null && filterBean.getDTBNYJYFilterList().length > 0) {
			readDataMapper.setDTBNYJYFilter(filterBean.getDTBNYJYFilterList());
		}
		
		
		//生成文档
		
	}
}
