package com.zdqz.sample.service.impl;

import java.io.File;
import java.io.FileInputStream;
import java.util.Date;
import java.util.List;

import org.apache.commons.io.FileUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.zdqz.common.config.ZdqzConfig;
import com.zdqz.common.utils.DateUtils;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.common.utils.uuid.UUID;
import com.zdqz.read.domain.ReadData;
import com.zdqz.read.service.IReadDataService;
import com.zdqz.sample.domain.SampleExperiment;
import com.zdqz.sample.mapper.SampleExperimentMapper;
import com.zdqz.sample.service.ISampleExperimentService;

/**
 * 解读管理Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-05
 */
@Service
public class SampleExperimentServiceImpl implements ISampleExperimentService {
	@Autowired
	private SampleExperimentMapper sampleExperimentMapper;

	@Autowired
	private IReadDataService readDataService;

	public SampleExperiment selectSampleExperimentById(Long id) {
		return sampleExperimentMapper.selectSampleExperimentById(id);
	}

	public List<SampleExperiment> selectSampleExperimentList(SampleExperiment sampleExperiment) {
		return sampleExperimentMapper.selectSampleExperimentList(sampleExperiment);
	}

	public int insertSampleExperiment(SampleExperiment sampleExperiment) {
		sampleExperiment.setCreateTime(DateUtils.getNowDate());
		return sampleExperimentMapper.insertSampleExperiment(sampleExperiment);
	}

	public int updateSampleExperiment(SampleExperiment sampleExperiment) {
		sampleExperiment.setUpdateTime(DateUtils.getNowDate());
		return sampleExperimentMapper.updateSampleExperiment(sampleExperiment);
	}

	public int deleteSampleExperimentByIds(Long[] ids) {
		return sampleExperimentMapper.deleteSampleExperimentByIds(ids);
	}

	public int deleteSampleExperimentById(Long id) {
		return sampleExperimentMapper.deleteSampleExperimentById(id);
	}

	@Transactional(rollbackFor = Exception.class)
	public void readData(Long id) throws Exception {
		SampleExperiment se = selectSampleExperimentById(id);
		if(se == null) {
			throw new NullPointerException("实验数据不存在");
		}
		se.setStatus(2L);
		se.setDealTime(new Date());
		se.setGeneratorStatus(1L);
		sampleExperimentMapper.updateSampleExperiment(se);
		
		File f = new File(ZdqzConfig.getReadFilePath());
		if(!f.exists()) {	//文件夹不存在，默认创建
			f.mkdirs();
		}
		for (File ff : f.listFiles()) {
			if(ff.isFile() && ff.getName().indexOf(se.getExperimentCode()+"_") != -1) {	//说明是文件并且含有实验编号
				//文件复制到备份地方
				FileUtils.copyFileToDirectory(ff, new File(ZdqzConfig.getBakPath()));
				//文件解析
				FileInputStream fis = new FileInputStream(ff);
				readDataService.importData(se.getId(),new ExcelUtil<ReadData>(ReadData.class).importExcel(fis));
				fis.close();
				// 文件删除
				ff.deleteOnExit();
				break;
			}
		}
	}

	@Override
	public void generator(Long id) {
		SampleExperiment se = selectSampleExperimentById(id);
		if(se == null) {
			throw new NullPointerException("实验数据不存在");
		}
		se.setGeneratorStatus(2L);
		se.setGeneratorTime(new Date());
		String fileName = UUID.randomUUID().toString().replace("-","");
		se.setGeneratorFile(fileName+".pdf");
		sampleExperimentMapper.updateSampleExperiment(se);
		
		//生成文档
	}
}
