package com.zdqz.sample.service.impl;

import java.util.List;
import com.zdqz.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zdqz.sample.mapper.SampleTypeMapper;
import com.zdqz.sample.domain.SampleType;
import com.zdqz.sample.service.ISampleTypeService;

/**
 * 样本类型Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@Service
public class SampleTypeServiceImpl implements ISampleTypeService 
{
    @Autowired
    private SampleTypeMapper sampleTypeMapper;

    /**
     * 查询样本类型
     * 
     * @param id 样本类型主键
     * @return 样本类型
     */
    @Override
    public SampleType selectSampleTypeById(Long id)
    {
        return sampleTypeMapper.selectSampleTypeById(id);
    }

    /**
     * 查询样本类型列表
     * 
     * @param sampleType 样本类型
     * @return 样本类型
     */
    @Override
    public List<SampleType> selectSampleTypeList(SampleType sampleType)
    {
        return sampleTypeMapper.selectSampleTypeList(sampleType);
    }

    /**
     * 新增样本类型
     * 
     * @param sampleType 样本类型
     * @return 结果
     */
    @Override
    public int insertSampleType(SampleType sampleType)
    {
        sampleType.setCreateTime(DateUtils.getNowDate());
        return sampleTypeMapper.insertSampleType(sampleType);
    }

    /**
     * 修改样本类型
     * 
     * @param sampleType 样本类型
     * @return 结果
     */
    @Override
    public int updateSampleType(SampleType sampleType)
    {
        sampleType.setUpdateTime(DateUtils.getNowDate());
        return sampleTypeMapper.updateSampleType(sampleType);
    }

    /**
     * 批量删除样本类型
     * 
     * @param ids 需要删除的样本类型主键
     * @return 结果
     */
    @Override
    public int deleteSampleTypeByIds(Long[] ids)
    {
        return sampleTypeMapper.deleteSampleTypeByIds(ids);
    }

    /**
     * 删除样本类型信息
     * 
     * @param id 样本类型主键
     * @return 结果
     */
    @Override
    public int deleteSampleTypeById(Long id)
    {
        return sampleTypeMapper.deleteSampleTypeById(id);
    }
}
