package com.zdqz.sample.tool;


import java.io.ByteArrayOutputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.StringWriter;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.io.IOUtils;

import com.itextpdf.html2pdf.ConverterProperties;
import com.itextpdf.html2pdf.HtmlConverter;
import com.itextpdf.kernel.pdf.PdfDocument;
import com.itextpdf.kernel.pdf.PdfWriter;

import freemarker.cache.ClassTemplateLoader;
import freemarker.template.Configuration;
import freemarker.template.Template;

public class PdfTools {

	
	private static final String templatesPath = "/templates/";
    private static final String fontsPath = "/fonts/simhei.ttf";
    private static final String templatesName = "template.html";

    
    
    public static void main(String[] args) throws FileNotFoundException, IOException, Exception {
		IOUtils.write(generatePDF(new HashMap<String, Object>()), new FileOutputStream("D:/abc.pdf"));
	}
    
    
    /**
     * 使用Freemarker引擎加载HTML模板文件并填充变量值，并将HTML字符串转换为PDF文件
     *
     * @param data             模板要填充的数据
     * @throws Exception
     */
    public static byte[] generatePDF(Map<String, Object> data) throws Exception {
        Configuration config = new Configuration(Configuration.getVersion());
        // 设置Freemarker引擎的模板路径
        config.setTemplateLoader(new ClassTemplateLoader(PdfTools.class, templatesPath));
        config.setDefaultEncoding("UTF-8");
        Template template = config.getTemplate(templatesName);
        StringWriter out = new StringWriter();
        template.process(data, out);
        out.flush();
        // 使用Freemarker引擎加载HTML模板文件并填充变量值
        String htmlContent = out.toString();
        byte[] bytes = convertHtmlToPdf(htmlContent);
        return bytes;
    }

    /**
     * 使用iText 7将HTML字符串转换为PDF文件，并返回PDF文件的二进制数据
     *
     * @param htmlString    待转换的HTML字符串
     * @return              返回生成的PDF文件内容
     * @throws IOException
     */
    private static byte[] convertHtmlToPdf(String htmlString) throws IOException {
        ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
        PdfWriter writer = new PdfWriter(outputStream);
        PdfDocument pdf = new PdfDocument(writer);
//        Document document = new Document(pdf, PageSize.A4);
//        // 设置左、右、上、下四个边距的值，以点（pt）为单位
//        document.setMargins(2, 4, 2, 2);
        // 设置中文字体
//        FontSet fontSet = new FontSet();
//        fontSet.addFont(fontsPath);
//        FontProvider fontProvider = new FontProvider(fontSet);
        ConverterProperties converterProps = new ConverterProperties();
//        converterProps.setFontProvider(fontProvider);
        // 调用HtmlConverter类的convertToPdf函数，将HTML字符串转换为PDF文件
        HtmlConverter.convertToPdf(htmlString, pdf,converterProps);
        pdf.close();
        // 将PDF文件转换为字节数组并返回
        return outputStream.toByteArray();
    }
}
