package com.zdqz.system.controller;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.zdqz.common.annotation.Log;
import com.zdqz.common.core.controller.BaseController;
import com.zdqz.common.core.domain.AjaxResult;
import com.zdqz.common.core.page.TableDataInfo;
import com.zdqz.common.enums.BusinessType;
import com.zdqz.common.utils.poi.ExcelUtil;
import com.zdqz.system.domain.SysArea;
import com.zdqz.system.service.ISysAreaService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

/**
 * 全球地区库Controller
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@RestController
@RequestMapping("/system/area")
@Api(value="国际区域接口",tags="国际区域接口标签")
public class SysAreaController extends BaseController {
	@Autowired
	private ISysAreaService sysAreaService;

	/**
	 * 查询全球地区库列表
	 */
	@PreAuthorize("@ss.hasPermi('system:area:list')")
	@GetMapping("/list")
	public TableDataInfo list(SysArea sysArea) {
		startPage();
		List<SysArea> list = sysAreaService.selectSysAreaList(sysArea);
		return getDataTable(list);
	}

	/**
	 * 导出全球地区库列表
	 */
	@PreAuthorize("@ss.hasPermi('system:area:export')")
	@Log(title = "全球地区库", businessType = BusinessType.EXPORT)
	@PostMapping("/export")
	public void export(HttpServletResponse response, SysArea sysArea) {
		List<SysArea> list = sysAreaService.selectSysAreaList(sysArea);
		ExcelUtil<SysArea> util = new ExcelUtil<SysArea>(SysArea.class);
		util.exportExcel(response, list, "全球地区库数据");
	}

	/**
	 * 获取全球地区库详细信息
	 */
	@PreAuthorize("@ss.hasPermi('system:area:query')")
	@GetMapping(value = "/{areaId}")
	public AjaxResult getInfo(@PathVariable("areaId") String areaId) {
		return success(sysAreaService.selectSysAreaByAreaId(areaId));
	}

	/**
	 * 新增全球地区库
	 */
	@PreAuthorize("@ss.hasPermi('system:area:add')")
	@Log(title = "全球地区库", businessType = BusinessType.INSERT)
	@PostMapping
	public AjaxResult add(@RequestBody SysArea sysArea) {
		return toAjax(sysAreaService.insertSysArea(sysArea));
	}

	/**
	 * 修改全球地区库
	 */
	@PreAuthorize("@ss.hasPermi('system:area:edit')")
	@Log(title = "全球地区库", businessType = BusinessType.UPDATE)
	@PutMapping
	public AjaxResult edit(@RequestBody SysArea sysArea) {
		return toAjax(sysAreaService.updateSysArea(sysArea));
	}

	/**
	 * 删除全球地区库
	 */
	@PreAuthorize("@ss.hasPermi('system:area:remove')")
	@Log(title = "全球地区库", businessType = BusinessType.DELETE)
	@DeleteMapping("/{areaIds}")
	public AjaxResult remove(@PathVariable String[] areaIds) {
		return toAjax(sysAreaService.deleteSysAreaByAreaIds(areaIds));
	}
	
	
	@ApiOperation("根据父节点编码获取区域列表")
	@GetMapping("/getAreaByParentId/{parentId}")
	@ApiImplicitParam(name = "parentId", value = "父节点编码", required = true, dataType = "int", paramType = "path", dataTypeClass = Integer.class)
	public AjaxResult getAreaByParentCode(@PathVariable Integer parentId) {
		return success(sysAreaService.getAreaByParentId(parentId));
	}
}
