package com.zdqz.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zdqz.system.mapper.SysAreaMapper;
import com.zdqz.system.domain.SysArea;
import com.zdqz.system.service.ISysAreaService;

/**
 * 全球地区库Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-04
 */
@Service
public class SysAreaServiceImpl implements ISysAreaService {
	@Autowired
	private SysAreaMapper sysAreaMapper;

	/**
	 * 查询全球地区库
	 * 
	 * @param areaId 全球地区库主键
	 * @return 全球地区库
	 */
	@Override
	public SysArea selectSysAreaByAreaId(String areaId) {
		return sysAreaMapper.selectSysAreaByAreaId(areaId);
	}

	/**
	 * 查询全球地区库列表
	 * 
	 * @param sysArea 全球地区库
	 * @return 全球地区库
	 */
	@Override
	public List<SysArea> selectSysAreaList(SysArea sysArea) {
		return sysAreaMapper.selectSysAreaList(sysArea);
	}

	/**
	 * 新增全球地区库
	 * 
	 * @param sysArea 全球地区库
	 * @return 结果
	 */
	@Override
	public int insertSysArea(SysArea sysArea) {
		return sysAreaMapper.insertSysArea(sysArea);
	}

	/**
	 * 修改全球地区库
	 * 
	 * @param sysArea 全球地区库
	 * @return 结果
	 */
	@Override
	public int updateSysArea(SysArea sysArea) {
		return sysAreaMapper.updateSysArea(sysArea);
	}

	/**
	 * 批量删除全球地区库
	 * 
	 * @param areaIds 需要删除的全球地区库主键
	 * @return 结果
	 */
	@Override
	public int deleteSysAreaByAreaIds(String[] areaIds) {
		return sysAreaMapper.deleteSysAreaByAreaIds(areaIds);
	}

	/**
	 * 删除全球地区库信息
	 * 
	 * @param areaId 全球地区库主键
	 * @return 结果
	 */
	@Override
	public int deleteSysAreaByAreaId(String areaId) {
		return sysAreaMapper.deleteSysAreaByAreaId(areaId);
	}

	@Override
	public List<SysArea> getAreaByParentId(Integer parentId) {
		SysArea sysArea = new SysArea();
		sysArea.setAreaParentId(parentId+"");
		return selectSysAreaList(sysArea);
	}
}
