package com.zdqz.system.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.zdqz.system.domain.SysCnarea;
import com.zdqz.system.mapper.SysCnareaMapper;
import com.zdqz.system.service.ISysCnareaService;

/**
 * 中国行政区域Service业务层处理
 * 
 * @author 攻心小虫
 * @date 2025-06-03
 */
@Service
public class SysCnareaServiceImpl implements ISysCnareaService {
	
	@Autowired
	private SysCnareaMapper sysCnareaMapper;

	/**
	 * 查询中国行政区域
	 * 
	 * @param id 中国行政区域主键
	 * @return 中国行政区域
	 */
	@Override
	public SysCnarea selectSysCnareaById(String id) {
		return sysCnareaMapper.selectSysCnareaById(id);
	}

	/**
	 * 查询中国行政区域列表
	 * 
	 * @param sysCnarea 中国行政区域
	 * @return 中国行政区域
	 */
	@Override
	public List<SysCnarea> selectSysCnareaList(SysCnarea sysCnarea) {
		return sysCnareaMapper.selectSysCnareaList(sysCnarea);
	}

	/**
	 * 新增中国行政区域
	 * 
	 * @param sysCnarea 中国行政区域
	 * @return 结果
	 */
	@Override
	public int insertSysCnarea(SysCnarea sysCnarea) {
		return sysCnareaMapper.insertSysCnarea(sysCnarea);
	}

	/**
	 * 修改中国行政区域
	 * 
	 * @param sysCnarea 中国行政区域
	 * @return 结果
	 */
	@Override
	public int updateSysCnarea(SysCnarea sysCnarea) {
		return sysCnareaMapper.updateSysCnarea(sysCnarea);
	}

	/**
	 * 批量删除中国行政区域
	 * 
	 * @param ids 需要删除的中国行政区域主键
	 * @return 结果
	 */
	@Override
	public int deleteSysCnareaByIds(String[] ids) {
		return sysCnareaMapper.deleteSysCnareaByIds(ids);
	}

	/**
	 * 删除中国行政区域信息
	 * 
	 * @param id 中国行政区域主键
	 * @return 结果
	 */
	@Override
	public int deleteSysCnareaById(String id) {
		return sysCnareaMapper.deleteSysCnareaById(id);
	}

	@Override
	public List<SysCnarea> getAreaByParentId(String parentId) {
		SysCnarea sysCnarea = new SysCnarea();
		sysCnarea.setParentCode(parentId);
		return selectSysCnareaList(sysCnarea);
	}
}
